@@ -1,7 +1,6 @@
 ##################################################
 package Log::Log4perl::Config;
 ##################################################
-
 use 5.006;
 use strict;
 use warnings;
@@ -499,9 +498,9 @@ sub get_appender_by_name {
 ###########################################
     my($data, $name, $appenders_created) = @_;
 
-    if ($appenders_created->{$name}) {
+    if (exists $appenders_created->{$name}) {
         return $appenders_created->{$name};
-    }else{
+    } else {
         return $data->{appender}->{$name}->{value};
     }
 }
